@@ -4,7 +4,7 @@
 #> open https://flavjack.github.io/inti/
 #> open https://flavjack.shinyapps.io/yupanapro/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2020-10-25
+#> date .: 2020-11-18
 # -------------------------------------------------------------------------
 
 # -------------------------------------------------------------------------
@@ -26,12 +26,11 @@ library(shinydashboard)
 library(ggpubr)
 library(FactoMineR)
 library(corrplot)
-library(BiocManager)
 
-options(repos = BiocManager::repositories())
 options("googleAuthR.scopes.selected" = c("https://www.googleapis.com/auth/spreadsheets"
                                           , "https://www.googleapis.com/auth/userinfo.email"
                                           ))
+
 options(gargle_oob_default = TRUE)
 options(shiny.port = 1221)
 
@@ -42,6 +41,7 @@ if (file.exists("www/cloud.json")) gar_set_client(web_json = "www/cloud.json")
 # -------------------------------------------------------------------------
 
 shinyServer(function(input, output, session) {
+  
 
 # close auto local session ------------------------------------------------
 
@@ -57,9 +57,11 @@ observe({
 
 # longin vs local ---------------------------------------------------------
 
-  access_token <<- moduleServer(id = "js_token"
-                                , module = googleAuth_js)
+  access_token <- moduleServer(id = "js_token"
+                               , module = googleAuth_js)
   
+# -------------------------------------------------------------------------
+
   output$login <- renderUI({
     
     if (file.exists("www/cloud.json")) {
@@ -69,9 +71,9 @@ observe({
                       , logout_text = "LogOut"
                       )
       
-    } else {
+      } else {
       
-      actionButton("do_something", "Local", class = "btn-success")
+      actionButton("local_user", "Local", class = "btn-success")
       
     }
       
@@ -197,7 +199,6 @@ observe({
 
       } else { fbsmrvar <- NULL }
     
-    
   })
 
 # Yupana: Fieldbook -------------------------------------------------------
@@ -342,14 +343,16 @@ observe({
       fbsmr <- fieldbook_summary(data = fieldbook()
                                  , last_factor = input$last_factor
                                  , model_facts = input$model_facts
-                                 , comp_facts = paste0(input$comp_facts, collapse = ":")
+                                 , comp_facts = paste0(input$comp_facts
+                                                       , collapse = ":")
                                  , test_comp = input$test_comp
                                  , sig_level = input$sig_level
       )
 
       if ( !input$fbsmrvars_gsheet %in% sheet_names(gs()) ) {
 
-        sheet_add(ss = gs(), .after = input$fieldbook_gsheet, sheet = input$fbsmrvars_gsheet)
+        sheet_add(ss = gs(), .after = input$fieldbook_gsheet
+                  , sheet = input$fbsmrvars_gsheet)
 
         fbsmr %>% sheet_write(ss = gs(), sheet = input$fbsmrvars_gsheet)
 
@@ -567,7 +570,7 @@ observe({
     
     })
 
-  
+  if (file.exists("www/analytics.r")) { source("www/analytics.r", local = T) }
 
   # -------------------------------------------------------------------------
 
@@ -835,7 +838,7 @@ observe({
     
     if ( input$graph_sheets %in% sheet_names(gs()) ) {
       
-      plottb <<- gs() %>%
+      plottb <- gs() %>%
         range_read( input$graph_sheets )
       
     } else {"Choose a summary table"}
